@@ -9,9 +9,16 @@ use parking_lot::Mutex;
 /// Framework context given to all command functions, this struct contains all the necessary
 /// items to respond the interaction and access shared data.
 pub struct SlashContext<'a, D> {
+    /// The [http client](Client) used by the framework.
     pub http_client: &'a Client,
+    /// The application id provided to the framework.
+    pub application_id: Id<ApplicationMarker>,
+    /// An [interaction client](InteractionClient) made out of the framework's [http client](Client)
+    pub interaction_client: InteractionClient<'a>,
+    /// The data shared across the framework.
     pub data: &'a D,
     waiters: &'a Mutex<Vec<WaiterSender>>,
+    /// The interaction itself.
     pub interaction: ApplicationCommand,
 }
 
@@ -19,6 +26,8 @@ impl<'a, D> Clone for SlashContext<'a, D> {
     fn clone(&self) -> Self {
         SlashContext {
             http_client: &self.http_client,
+            application_id: self.application_id,
+            interaction_client: self.http_client.interaction(self.application_id),
             data: &self.data,
             waiters: &self.waiters,
             interaction: self.interaction.clone(),
@@ -30,12 +39,16 @@ impl<'a, D> SlashContext<'a, D> {
     /// Creates a new context.
     pub(crate) fn new(
         http_client: &'a Client,
+        application_id: Id<ApplicationMarker>,
         data: &'a D,
         waiters: &'a Mutex<Vec<WaiterSender>>,
         interaction: ApplicationCommand,
     ) -> Self {
+        let interaction_client = http_client.interaction(application_id);
         Self {
             http_client,
+            application_id,
+            interaction_client,
             data,
             waiters,
             interaction,
@@ -46,8 +59,7 @@ impl<'a, D> SlashContext<'a, D> {
     ///
     /// When this method is used [update_response](Self::update_response) has to be used to edit the response.
     pub async fn acknowledge(&self) -> CommandResult {
-        self
-            .http_client
+        self.interaction_client
             .interaction_callback(
                 self.interaction.id,
                 &self.interaction.token,
@@ -76,10 +88,7 @@ impl<'a, D> SlashContext<'a, D> {
     where
         F: FnOnce(UpdateOriginalResponse<'a>) -> UpdateOriginalResponse<'a>,
     {
-        let mut update = self
-            .http_client
-            .update_interaction_original(&self.interaction.token)?;
-        update = fun(update);
+        let update = fun(self.interaction_client.update_interaction_original(&self.interaction.token));
         Ok(update
             .exec()
             .await?
